@@ -81,8 +81,9 @@ class Menu_Manager(object):
     @property
     def actual_menu(self):
         return self.__menu
+    
     @actual_menu.setter
-    def setter(self,__val):
+    def actual_menu(self,__val):
         if type(__val)==Menu:
             self.__menu = __val
             self.__menu.setup()
@@ -132,13 +133,12 @@ class Menu_Manager(object):
         exit()
 
 class sprite(py.sprite.Sprite):
-    __manager:Menu_Manager = None
-
-    def __init__(self,name,path,isactive=True,layer=0):
+    def __init__(self,name,path,manager:Menu_Manager,isactive=True,layer=0):
         super().__init__()
         self.name = name
         self.layer = layer
         self.isactive = isactive
+        self._manager = manager
         
         self.handles = []
         try:
@@ -159,14 +159,14 @@ class sprite(py.sprite.Sprite):
             if parent:
                 x = int(parent.image.get_width()*pos.x) + parent.position.x
             else:
-                x = int(self.__manager.screen.get_width()*pos.x)
+                x = int(self._manager.screen.get_width()*pos.x)
         elif parent:
             x = pos.x + parent.position.x
         if type(pos.y)==float:
             if parent:
                 y = int(parent.image.get_height()*pos.y) + parent.position.y
             else:
-                y = int(self.__manager.screen.get_height()*pos.y)
+                y = int(self._manager.screen.get_height()*pos.y)
         elif parent:
             y = pos.y + parent.position.y
         
@@ -222,18 +222,19 @@ class sprite(py.sprite.Sprite):
 
 class textZone(sprite):
     """class pour ajouter automatiquement du text"""
-    def __init__(self, name,size:Vector2, isactive=True,text_color='white', layer=0):
+    def __init__(self, name,size:Vector2,manager, isactive=True,text_color='white', layer=0):
         self.name = name
         self.isactive = isactive
         self.layer = layer
         self.handles = []
+        self._manager = manager
 
         self.image = py.Surface(size(),flags=py.SRCALPHA)
         self.rect = self.image.get_rect(topleft=(0,0))
 
         self.text_color = text_color
-        self.FONT = py.font.Font(self.__manager.FONT,36)
-        self.font_path = self.__manager.FONT
+        self.FONT = py.font.Font(self._manager.FONT,36)
+        self.font_path = self._manager.FONT
         self.text = ""
         self.align_center = False
 
@@ -309,8 +310,8 @@ class Button(sprite):
     """
     classe de bouton simple avec méthode rapide pour Event et On_Click
     """
-    def __init__(self,name,path,isactive=True,layer=0):
-        super().__init__(name,path,isactive,layer)
+    def __init__(self,name,path,manager:Menu_Manager,isactive=True,layer=0):
+        super().__init__(name,path,manager,isactive,layer)
 
     def on_click(self,_effect=None):
         """
@@ -324,13 +325,13 @@ class Button(sprite):
                         if self.check_layer():
                             func(*args,**kargs)
                             if _effect != None:
-                                self.__manager.play_effect(_effect)
+                                self._manager.play_effect(_effect)
             self.handles.append(wrap)
         
         return Wrap
     
     def check_layer(self):
-        for _sprite in self.__manager.actual_menu.sprites():
+        for _sprite in self._manager.actual_menu.sprites():
             if _sprite.isactive:
                 if _sprite.rect.collidepoint(py.mouse.get_pos()) and _sprite.layer > self.layer:
                     return False
@@ -353,9 +354,9 @@ class InputBox(sprite):
     """
     class de InputBox autonome, permet de rentrer du texte facilement
     """
-    def __init__(self,name,path,paceHolder='Enter text...',color='black',text_color='grey',alter_text_color="white",max_char=16,isactive=True,layer=0):
+    def __init__(self,name,path,manager:Menu_Manager,paceHolder='Enter text...',color='black',text_color='grey',alter_text_color="white",max_char=16,isactive=True,layer=0):
 
-        super().__init__(name,path,isactive,layer)
+        super().__init__(name,path,manager,isactive,layer)
 
         self.color = Color(color)
         self.text = ''
@@ -366,9 +367,9 @@ class InputBox(sprite):
         self.text_color_active = Color(alter_text_color)
 
         self.text_size = self.get_text_size()
-        if self.__manager.FONT == None:
+        if self._manager.FONT == None:
             raise AttributeError("You must define the FONT of your MenuManager to use Inputbox")
-        self.FONT = py.font.Font(self.__manager.FONT,self.text_size)
+        self.FONT = py.font.Font(self._manager.FONT,self.text_size)
         self.txt_surface = self.FONT.render(self.paceHolder, True, self.text_color)
         self.active = False
 
@@ -434,17 +435,17 @@ class AlertBox(sprite):
     """
     class de alertbox autonome, permet de rentrer d'afficher une erreur facilement
     """
-    def __init__(self,name,path,color='black',text_color='grey',padding=0.05,isactive=True,layer=0):
-        super().__init__(name,path,isactive,layer)
+    def __init__(self,name,path,manager:Menu_Manager,color='black',text_color='grey',padding=0.05,isactive=True,layer=0):
+        super().__init__(name,path,manager,isactive,layer)
 
         self.color = Color(color)
         self.text = ''
         self.text_color = Color(text_color)
         self.padding = padding
 
-        if self.__manager.FONT == None:
+        if self._manager.FONT == None:
             raise AttributeError("You must define the FONT of your MenuManager to use Inputbox")
-        self.FONT = py.font.Font(self.__manager.FONT,self.text_size)
+        self.FONT = py.font.Font(self._manager.FONT,self.text_size)
 
         self.childs:list[Button] = list()
   
@@ -574,7 +575,6 @@ class Menu(py.sprite.Group):
         _sprite = func()
         if sprite in _sprite.__class__.__bases__ or type(_sprite)==sprite:
             self.add(_sprite)
-            _sprite.__manager = self._manager
         else:
             raise TypeError("You must return a sprite based class to add, type returned was :",type(_sprite))
 
